def print_list(the_list,indent=False,level=0):
        for my_list in the_list:
                if isinstance(my_list,list):
                        print_list(my_list,indent,level+1)

                else:
                        if indent:
                                for tab_space in range(level):
                                        print('\t',end='')
                        else:
                                print(my_list)




from distutils.core import setup

setup(
	name 		= 'asveloper_nester',
	version 	= '1.3.0',
	py_modules 	= ['asveloper_nester'],
	author 		= 'Arslan Nasir',
	author_email 	= 'arslan@asveloper.com',
	url 		= 'http://www.asveloper.com',
	description 	= 'Nester allow you to print lists either nested list exists or not'
)
